@@ -89,7 +89,7 @@ command_loop( string_t prompt, command_t *commands[] )
     { 
 #ifdef READLINE
       command_line = readline(p);
-      if (! g_utf8_validate( command_line, -1, NULL ))
+      if (command_line != NULL && ! g_utf8_validate( command_line, -1, NULL ))
 	complain( "Illegal UTF-8 character." );
 #else
       printf( "%s> ", prompt );
