@@ -3,7 +3,7 @@
 
 (provide 'malaga)
 
-(defconst malaga-version "7.9" "Version of Malaga.")
+(defconst malaga-version "7.11" "Version of Malaga.")
 
 ;; malaga mode (for editing malaga files). ====================================
 
@@ -648,8 +648,10 @@ when malaga, mallex or malmake is started.")
   "Read the name of the malaga project file."
   (setq malaga-project-file 
 	(expand-file-name 
-	 (read-file-name "Project file: " "" 
-			 malaga-project-file t malaga-project-file))))
+	 (read-file-name "Project file: " 
+			 (file-name-directory malaga-project-file) 
+			 malaga-project-file t 
+			 (file-name-nondirectory malaga-project-file)))))
 
 (defun malaga (project-file)
   "Run malaga with PROJECT-FILE in buffer *malaga*."
