@@ -563,13 +563,13 @@ read_project_file( string_t project_file )
 static command_t *malaga_options[] = 
 { 
   &alias_option, &auto_result_option, &auto_tree_option, 
-  &auto_variables_option, &cache_size_option, &display_line_option, 
+  &auto_variables_option, &cache_size_option, &display_cmd_option, 
   &error_format_option, &hidden_option, &mor_incomplete_option, 
   &mor_out_filter_option, &mor_pruning_option, &result_format_option,
   &result_list_option, &robust_rule_option, &roman_hangul_option, 
   &sort_records_option, &switch_option, &syn_incomplete_option, 
   &syn_in_filter_option, &syn_out_filter_option, &syn_pruning_option,
-  &transmit_line_option, &unknown_format_option, &use_display_option, 
+  &transmit_cmd_option, &unknown_format_option, &use_display_option, 
   NULL
 };
 
