@@ -391,8 +391,8 @@ static command_t allo_format_option =
 static command_t *mallex_options[] = 
 { 
   &alias_option, &allo_format_option, &auto_variables_option, 
-  &display_line_option, &hidden_option, &roman_hangul_option, 
-  &sort_records_option, &switch_option, &transmit_line_option, 
+  &display_cmd_option, &hidden_option, &roman_hangul_option, 
+  &sort_records_option, &switch_option, &transmit_cmd_option, 
   &use_display_option,
   NULL
 };
